@@ -31,6 +31,10 @@
 #' \code{\link[=emmGrid-class]{emmGrid}} objects. Such a list is returned,
 #' for example, by \code{\link{emmeans}} with a two-sided formula or a list as its
 #' \code{specs} argument. Several methods for this class are provided, as detailed below.
+#' Typically, these methods just quietly do the same thing as their \code{EmmGrid}
+#' methods, using the first element of the list. You can specify \code{which}
+#' to select a different element, or just run the corresponding \code{emmGrid}
+#' method on \code{object[[k]]}.
 #' 
 #' @param object,x an object of class \code{emm_list}
 #' @param ... additional arguments passed to corresponding \code{emmGrid} method
@@ -45,30 +49,12 @@
 #' @order 1
 NULL
 
-#' @rdname emm_list-object
-#' @order 99
-#' 
-#' @note \code{I_bet()} provides a default value for \code{which} noisily.
-#' It is used in cases where users
-#' most likely intended to call a method for an \code{emmGrid} object
-#' rather than an \code{emm_list} object. 
-#' An informative message is displayed
-#' and then the \code{which}th element is returned. 
-#'
-#' @export
-I_bet = function(which) {
-    message("I bet you wanted to call this with just object[[", which, "]]",
-            " - use '[[]]' or which' if I'm wrong.\n", 
-            "See '? emm_list' for more information")
-    which
-}
-
 # Internal utility to noisily return one of an emm_list
 # Call with ... argument so that message is suppressed if we specify 'which'
 .chk.list = function(object, which, ...) {
     if (inherits(object, "emm_list")) {
         if (missing(which))
-            which = I_bet(1)
+            which = 1
         object = object[[which]]
     }
     object
@@ -77,8 +63,14 @@ I_bet = function(which) {
 # My own lapply() function that drops when the dimension is 1
 .lapply = function(...) {
     rtn = lapply(...)
-    if (length(rtn) == 1)   rtn[[1]]
-    else                    rtn
+    if (length(rtn) == 1)   {
+        rtn = rtn[[1]]
+        class(rtn) = c("summary_emm", "data.frame")
+    }
+    else                    {
+        class(rtn) = c("summary_eml", "list")
+    }
+    rtn
 }
 
 
@@ -103,11 +95,30 @@ str.emm_list = function(object, ...) {
 #' @method summary emm_list
 #' @rdname emm_list-object
 #' @order 13
-summary.emm_list <- function(object, ..., which = seq_along(object))
-    .lapply(object[which], function(x) {
-        if (inherits(x, "summary.emmGrid"))  x
-        else summary.emmGrid(x, ...)
-    })
+summary.emm_list <- function(object, ..., which = seq_along(object)) {
+    # .lapply(object[which], function(x) {
+    #     if (inherits(x, "summary_emm"))  x
+    #     else summary.emmGrid(x, ...)
+    # })
+    if(length(which) == 1)
+        summary.emmGrid(object[[which]])
+    else
+        .lapply(object[which], \(x) summary.emmGrid(x, ...))
+}
+
+#' @export
+summary.summary_eml = function(object, ...) object
+#' @export
+as.data.frame.summary_eml = function(x, ...) {
+    for (i in seq_along(x))
+        attr(x[[i]], "digits") = getOption("digits")
+    x
+}
+#' @export
+print.summary_eml = function(x, ...) {
+    attr(x, "class") = NULL
+    print(x)
+}
 
 #' @export
 #' @method print emm_list
@@ -125,7 +136,7 @@ print.emm_list = function(x, ...) {
 #' @method contrast emm_list
 #' @rdname emm_list-object
 #' @order 3
-contrast.emm_list = function(object, ... , which = I_bet(1)) {
+contrast.emm_list = function(object, ... , which = 1) {
     .lapply(object[which], contrast, ...)
 }
 
@@ -133,7 +144,7 @@ contrast.emm_list = function(object, ... , which = I_bet(1)) {
 #' @method pairs emm_list
 #' @rdname emm_list-object
 #' @order 4
-pairs.emm_list = function(x, ..., which = I_bet(1)) {
+pairs.emm_list = function(x, ..., which = 1) {
     .lapply(x[which], pairs, ...)
 }
 
@@ -157,7 +168,7 @@ confint.emm_list = function(object, ..., which = seq_along(object)) {
 #' @method coef emm_list
 #' @rdname emm_list-object
 #' @order 9
-coef.emm_list = function(object, ..., which = I_bet(1)) {
+coef.emm_list = function(object, ..., which = 1) {
     .lapply(object[which], coef, ...)
 }
 
@@ -167,7 +178,7 @@ coef.emm_list = function(object, ..., which = I_bet(1)) {
 #' @rdname emm_list-object
 #' @order 8
 #' @note The \code{plot} method uses only the first element of \code{which}; the others are ignored.
-plot.emm_list = function(x, ..., which = I_bet(1)) {
+plot.emm_list = function(x, ..., which = 1) {
     plot.emmGrid(x[[which[1]]], ...)
 }
 
@@ -200,6 +211,9 @@ rbind.emm_list = function(..., which, adjust = "bonferroni") {
 #' See also \code{\link{rbind.emm_list}} and \code{\link{as.data.frame.emmGrid}}
 #' @method as.data.frame emm_list
 as.data.frame.emm_list = function(x, ...) {
+    if (length(x) > 1)
+        warning("Note: 'as.data.frame' has combined your ", length(x), " sets of results into one object,\n",
+                "and this affects things like adjusted P values. Refer to the annotations.")
     as.data.frame(rbind(x, ..., check.names = FALSE))
 }
 
@@ -229,14 +243,14 @@ as.emm_list = function(object, ...) {
 ### Others we won't document
 
 update.emm_list = function(object, ...)
-    update.emmGrid(object[[I_bet(1)]])
+    update.emmGrid(object[[1]])
 
 predict.emm_list = function(object, ...)
-    predict.emmGrid(object[[I_bet(1)]], ...)
+    predict.emmGrid(object[[1]], ...)
 
 vcov.emm_list = function(object, ...)
-    vcov.emmGrid(object[[I_bet(1)]], ...)
+    vcov.emmGrid(object[[1]], ...)
 
 xtable.emm_list = function(x, ...)
-    xtable.emmGrid(x[[I_bet(1)]], ...)
+    xtable.emmGrid(x[[1]], ...)
 
